@@ -1,8 +1,10 @@
-from mopidy.frontends.mpd.exceptions import (MpdArgError, MpdNoExistError,
-    MpdNotImplemented)
+from __future__ import unicode_literals
+
+from mopidy.frontends.mpd import translator
+from mopidy.frontends.mpd.exceptions import (
+    MpdArgError, MpdNoExistError, MpdNotImplemented)
 from mopidy.frontends.mpd.protocol import handle_request
-from mopidy.frontends.mpd.translator import (track_to_mpd_format,
-    tracks_to_mpd_format)
+
 
 @handle_request(r'^add "(?P<uri>[^"]*)"$')
 def add(context, uri):
@@ -20,14 +22,12 @@ def add(context, uri):
     """
     if not uri:
         return
-    for uri_scheme in context.backend.uri_schemes.get():
-        if uri.startswith(uri_scheme):
-            track = context.backend.library.lookup(uri).get()
-            if track is not None:
-                context.backend.current_playlist.add(track)
-                return
-    raise MpdNoExistError(
-        u'directory or file not found', command=u'add')
+    tracks = context.core.library.lookup(uri).get()
+    if tracks:
+        context.core.tracklist.add(tracks)
+        return
+    raise MpdNoExistError('directory or file not found', command='add')
+
 
 @handle_request(r'^addid "(?P<uri>[^"]*)"( "(?P<songpos>\d+)")*$')
 def addid(context, uri, songpos=None):
@@ -49,17 +49,17 @@ def addid(context, uri, songpos=None):
     - ``addid ""`` should return an error.
     """
     if not uri:
-        raise MpdNoExistError(u'No such song', command=u'addid')
+        raise MpdNoExistError('No such song', command='addid')
     if songpos is not None:
         songpos = int(songpos)
-    track = context.backend.library.lookup(uri).get()
-    if track is None:
-        raise MpdNoExistError(u'No such song', command=u'addid')
-    if songpos and songpos > context.backend.current_playlist.length.get():
-        raise MpdArgError(u'Bad song index', command=u'addid')
-    cp_track = context.backend.current_playlist.add(track,
-        at_position=songpos).get()
-    return ('Id', cp_track.cpid)
+    tracks = context.core.library.lookup(uri).get()
+    if not tracks:
+        raise MpdNoExistError('No such song', command='addid')
+    if songpos and songpos > context.core.tracklist.length.get():
+        raise MpdArgError('Bad song index', command='addid')
+    tl_tracks = context.core.tracklist.add(tracks, at_position=songpos).get()
+    return ('Id', tl_tracks[0].tlid)
+
 
 @handle_request(r'^delete "(?P<start>\d+):(?P<end>\d+)*"$')
 def delete_range(context, start, end=None):
@@ -74,26 +74,28 @@ def delete_range(context, start, end=None):
     if end is not None:
         end = int(end)
     else:
-        end = context.backend.current_playlist.length.get()
-    cp_tracks = context.backend.current_playlist.slice(start, end).get()
-    if not cp_tracks:
-        raise MpdArgError(u'Bad song index', command=u'delete')
-    for (cpid, _) in cp_tracks:
-        context.backend.current_playlist.remove(cpid=cpid)
+        end = context.core.tracklist.length.get()
+    tl_tracks = context.core.tracklist.slice(start, end).get()
+    if not tl_tracks:
+        raise MpdArgError('Bad song index', command='delete')
+    for (tlid, _) in tl_tracks:
+        context.core.tracklist.remove(tlid=tlid)
+
 
 @handle_request(r'^delete "(?P<songpos>\d+)"$')
 def delete_songpos(context, songpos):
     """See :meth:`delete_range`"""
     try:
         songpos = int(songpos)
-        (cpid, _) = context.backend.current_playlist.slice(
+        (tlid, _) = context.core.tracklist.slice(
             songpos, songpos + 1).get()[0]
-        context.backend.current_playlist.remove(cpid=cpid)
+        context.core.tracklist.remove(tlid=tlid)
     except IndexError:
-        raise MpdArgError(u'Bad song index', command=u'delete')
+        raise MpdArgError('Bad song index', command='delete')
 
-@handle_request(r'^deleteid "(?P<cpid>\d+)"$')
-def deleteid(context, cpid):
+
+@handle_request(r'^deleteid "(?P<tlid>\d+)"$')
+def deleteid(context, tlid):
     """
     *musicpd.org, current playlist section:*
 
@@ -101,13 +103,14 @@ def deleteid(context, cpid):
 
         Deletes the song ``SONGID`` from the playlist
     """
-    try:
-        cpid = int(cpid)
-        if context.backend.playback.current_cpid.get() == cpid:
-            context.backend.playback.next()
-        return context.backend.current_playlist.remove(cpid=cpid).get()
-    except LookupError:
-        raise MpdNoExistError(u'No such song', command=u'deleteid')
+    tlid = int(tlid)
+    tl_track = context.core.playback.current_tl_track.get()
+    if tl_track and tl_track.tlid == tlid:
+        context.core.playback.next()
+    tl_tracks = context.core.tracklist.remove(tlid=tlid).get()
+    if not tl_tracks:
+        raise MpdNoExistError('No such song', command='deleteid')
+
 
 @handle_request(r'^clear$')
 def clear(context):
@@ -118,7 +121,8 @@ def clear(context):
 
         Clears the current playlist.
     """
-    context.backend.current_playlist.clear()
+    context.core.tracklist.clear()
+
 
 @handle_request(r'^move "(?P<start>\d+):(?P<end>\d+)*" "(?P<to>\d+)"$')
 def move_range(context, start, to, end=None):
@@ -131,21 +135,23 @@ def move_range(context, start, to, end=None):
         ``TO`` in the playlist.
     """
     if end is None:
-        end = context.backend.current_playlist.length.get()
+        end = context.core.tracklist.length.get()
     start = int(start)
     end = int(end)
     to = int(to)
-    context.backend.current_playlist.move(start, end, to)
+    context.core.tracklist.move(start, end, to)
+
 
 @handle_request(r'^move "(?P<songpos>\d+)" "(?P<to>\d+)"$')
 def move_songpos(context, songpos, to):
     """See :meth:`move_range`."""
     songpos = int(songpos)
     to = int(to)
-    context.backend.current_playlist.move(songpos, songpos + 1, to)
+    context.core.tracklist.move(songpos, songpos + 1, to)
 
-@handle_request(r'^moveid "(?P<cpid>\d+)" "(?P<to>\d+)"$')
-def moveid(context, cpid, to):
+
+@handle_request(r'^moveid "(?P<tlid>\d+)" "(?P<to>\d+)"$')
+def moveid(context, tlid, to):
     """
     *musicpd.org, current playlist section:*
 
@@ -155,11 +161,14 @@ def moveid(context, cpid, to):
         the playlist. If ``TO`` is negative, it is relative to the current
         song in the playlist (if there is one).
     """
-    cpid = int(cpid)
+    tlid = int(tlid)
     to = int(to)
-    cp_track = context.backend.current_playlist.get(cpid=cpid).get()
-    position = context.backend.current_playlist.index(cp_track).get()
-    context.backend.current_playlist.move(position, position + 1, to)
+    tl_tracks = context.core.tracklist.filter(tlid=tlid).get()
+    if not tl_tracks:
+        raise MpdNoExistError('No such song', command='moveid')
+    position = context.core.tracklist.index(tl_tracks[0]).get()
+    context.core.tracklist.move(position, position + 1, to)
+
 
 @handle_request(r'^playlist$')
 def playlist(context):
@@ -176,6 +185,7 @@ def playlist(context):
     """
     return playlistinfo(context)
 
+
 @handle_request(r'^playlistfind (?P<tag>[^"]+) "(?P<needle>[^"]+)"$')
 @handle_request(r'^playlistfind "(?P<tag>[^"]+)" "(?P<needle>[^"]+)"$')
 def playlistfind(context, tag, needle):
@@ -191,16 +201,16 @@ def playlistfind(context, tag, needle):
     - does not add quotes around the tag.
     """
     if tag == 'filename':
-        try:
-            cp_track = context.backend.current_playlist.get(uri=needle).get()
-            position = context.backend.current_playlist.index(cp_track).get()
-            return track_to_mpd_format(cp_track, position=position)
-        except LookupError:
+        tl_tracks = context.core.tracklist.filter(uri=needle).get()
+        if not tl_tracks:
             return None
-    raise MpdNotImplemented # TODO
+        position = context.core.tracklist.index(tl_tracks[0]).get()
+        return translator.track_to_mpd_format(tl_tracks[0], position=position)
+    raise MpdNotImplemented  # TODO
 
-@handle_request(r'^playlistid( "(?P<cpid>\d+)")*$')
-def playlistid(context, cpid=None):
+
+@handle_request(r'^playlistid( "(?P<tlid>\d+)")*$')
+def playlistid(context, tlid=None):
     """
     *musicpd.org, current playlist section:*
 
@@ -209,24 +219,22 @@ def playlistid(context, cpid=None):
         Displays a list of songs in the playlist. ``SONGID`` is optional
         and specifies a single song to display info for.
     """
-    if cpid is not None:
-        try:
-            cpid = int(cpid)
-            cp_track = context.backend.current_playlist.get(cpid=cpid).get()
-            position = context.backend.current_playlist.index(cp_track).get()
-            return track_to_mpd_format(cp_track, position=position)
-        except LookupError:
-            raise MpdNoExistError(u'No such song', command=u'playlistid')
+    if tlid is not None:
+        tlid = int(tlid)
+        tl_tracks = context.core.tracklist.filter(tlid=tlid).get()
+        if not tl_tracks:
+            raise MpdNoExistError('No such song', command='playlistid')
+        position = context.core.tracklist.index(tl_tracks[0]).get()
+        return translator.track_to_mpd_format(tl_tracks[0], position=position)
     else:
-        return tracks_to_mpd_format(
-            context.backend.current_playlist.cp_tracks.get())
+        return translator.tracks_to_mpd_format(
+            context.core.tracklist.tl_tracks.get())
+
 
 @handle_request(r'^playlistinfo$')
-@handle_request(r'^playlistinfo "-1"$')
 @handle_request(r'^playlistinfo "(?P<songpos>-?\d+)"$')
 @handle_request(r'^playlistinfo "(?P<start>\d+):(?P<end>\d+)*"$')
-def playlistinfo(context, songpos=None,
-        start=None, end=None):
+def playlistinfo(context, songpos=None, start=None, end=None):
     """
     *musicpd.org, current playlist section:*
 
@@ -241,25 +249,28 @@ def playlistinfo(context, songpos=None,
     - uses negative indexes, like ``playlistinfo "-1"``, to request
       the entire playlist
     """
+    if songpos == '-1':
+        songpos = None
     if songpos is not None:
         songpos = int(songpos)
-        cp_track = context.backend.current_playlist.cp_tracks.get()[songpos]
-        return track_to_mpd_format(cp_track, position=songpos)
+        tl_track = context.core.tracklist.tl_tracks.get()[songpos]
+        return translator.track_to_mpd_format(tl_track, position=songpos)
     else:
         if start is None:
             start = 0
         start = int(start)
-        if not (0 <= start <= context.backend.current_playlist.length.get()):
-            raise MpdArgError(u'Bad song index', command=u'playlistinfo')
+        if not (0 <= start <= context.core.tracklist.length.get()):
+            raise MpdArgError('Bad song index', command='playlistinfo')
         if end is not None:
             end = int(end)
-            if end > context.backend.current_playlist.length.get():
+            if end > context.core.tracklist.length.get():
                 end = None
-        cp_tracks = context.backend.current_playlist.cp_tracks.get()
-        return tracks_to_mpd_format(cp_tracks, start, end)
+        tl_tracks = context.core.tracklist.tl_tracks.get()
+        return translator.tracks_to_mpd_format(tl_tracks, start, end)
+
 
 @handle_request(r'^playlistsearch "(?P<tag>[^"]+)" "(?P<needle>[^"]+)"$')
-@handle_request(r'^playlistsearch (?P<tag>\S+) "(?P<needle>[^"]+)"$')
+@handle_request(r'^playlistsearch (?P<tag>\w+) "(?P<needle>[^"]+)"$')
 def playlistsearch(context, tag, needle):
     """
     *musicpd.org, current playlist section:*
@@ -274,7 +285,8 @@ def playlistsearch(context, tag, needle):
     - does not add quotes around the tag
     - uses ``filename`` and ``any`` as tags
     """
-    raise MpdNotImplemented # TODO
+    raise MpdNotImplemented  # TODO
+
 
 @handle_request(r'^plchanges (?P<version>-?\d+)$')
 @handle_request(r'^plchanges "(?P<version>-?\d+)"$')
@@ -294,9 +306,10 @@ def plchanges(context, version):
     - Calls ``plchanges "-1"`` two times per second to get the entire playlist.
     """
     # XXX Naive implementation that returns all tracks as changed
-    if int(version) < context.backend.current_playlist.version:
-        return tracks_to_mpd_format(
-            context.backend.current_playlist.cp_tracks.get())
+    if int(version) < context.core.tracklist.version.get():
+        return translator.tracks_to_mpd_format(
+            context.core.tracklist.tl_tracks.get())
+
 
 @handle_request(r'^plchangesposid "(?P<version>\d+)"$')
 def plchangesposid(context, version):
@@ -313,14 +326,15 @@ def plchangesposid(context, version):
         ``playlistlength`` returned by status command.
     """
     # XXX Naive implementation that returns all tracks as changed
-    if int(version) != context.backend.current_playlist.version.get():
+    if int(version) != context.core.tracklist.version.get():
         result = []
-        for (position, (cpid, _)) in enumerate(
-                context.backend.current_playlist.cp_tracks.get()):
-            result.append((u'cpos', position))
-            result.append((u'Id', cpid))
+        for (position, (tlid, _)) in enumerate(
+                context.core.tracklist.tl_tracks.get()):
+            result.append(('cpos', position))
+            result.append(('Id', tlid))
         return result
 
+
 @handle_request(r'^shuffle$')
 @handle_request(r'^shuffle "(?P<start>\d+):(?P<end>\d+)*"$')
 def shuffle(context, start=None, end=None):
@@ -336,7 +350,8 @@ def shuffle(context, start=None, end=None):
         start = int(start)
     if end is not None:
         end = int(end)
-    context.backend.current_playlist.shuffle(start, end)
+    context.core.tracklist.shuffle(start, end)
+
 
 @handle_request(r'^swap "(?P<songpos1>\d+)" "(?P<songpos2>\d+)"$')
 def swap(context, songpos1, songpos2):
@@ -349,18 +364,19 @@ def swap(context, songpos1, songpos2):
     """
     songpos1 = int(songpos1)
     songpos2 = int(songpos2)
-    tracks = context.backend.current_playlist.tracks.get()
+    tracks = context.core.tracklist.tracks.get()
     song1 = tracks[songpos1]
     song2 = tracks[songpos2]
     del tracks[songpos1]
     tracks.insert(songpos1, song2)
     del tracks[songpos2]
     tracks.insert(songpos2, song1)
-    context.backend.current_playlist.clear()
-    context.backend.current_playlist.append(tracks)
+    context.core.tracklist.clear()
+    context.core.tracklist.add(tracks)
 
-@handle_request(r'^swapid "(?P<cpid1>\d+)" "(?P<cpid2>\d+)"$')
-def swapid(context, cpid1, cpid2):
+
+@handle_request(r'^swapid "(?P<tlid1>\d+)" "(?P<tlid2>\d+)"$')
+def swapid(context, tlid1, tlid2):
     """
     *musicpd.org, current playlist section:*
 
@@ -368,10 +384,12 @@ def swapid(context, cpid1, cpid2):
 
         Swaps the positions of ``SONG1`` and ``SONG2`` (both song ids).
     """
-    cpid1 = int(cpid1)
-    cpid2 = int(cpid2)
-    cp_track1 = context.backend.current_playlist.get(cpid=cpid1).get()
-    cp_track2 = context.backend.current_playlist.get(cpid=cpid2).get()
-    position1 = context.backend.current_playlist.index(cp_track1).get()
-    position2 = context.backend.current_playlist.index(cp_track2).get()
+    tlid1 = int(tlid1)
+    tlid2 = int(tlid2)
+    tl_tracks1 = context.core.tracklist.filter(tlid=tlid1).get()
+    tl_tracks2 = context.core.tracklist.filter(tlid=tlid2).get()
+    if not tl_tracks1 or not tl_tracks2:
+        raise MpdNoExistError('No such song', command='swapid')
+    position1 = context.core.tracklist.index(tl_tracks1[0]).get()
+    position2 = context.core.tracklist.index(tl_tracks2[0]).get()
     swap(context, position1, position2)
