@@ -1,34 +1,42 @@
+from __future__ import unicode_literals
+
 import re
 import shlex
 
 from mopidy.frontends.mpd.exceptions import MpdArgError, MpdNotImplemented
 from mopidy.frontends.mpd.protocol import handle_request, stored_playlists
-from mopidy.frontends.mpd.translator import playlist_to_mpd_format
+from mopidy.frontends.mpd.translator import tracks_to_mpd_format
+
 
 def _build_query(mpd_query):
     """
     Parses a MPD query string and converts it to the Mopidy query format.
     """
     query_pattern = (
-        r'"?(?:[Aa]lbum|[Aa]rtist|[Ff]ilename|[Tt]itle|[Aa]ny)"? "[^"]+"')
+        r'"?(?:[Aa]lbum|[Aa]rtist|[Ff]ile[name]*|[Tt]itle|[Aa]ny)"? "[^"]+"')
     query_parts = re.findall(query_pattern, mpd_query)
     query_part_pattern = (
-        r'"?(?P<field>([Aa]lbum|[Aa]rtist|[Ff]ilename|[Tt]itle|[Aa]ny))"? '
+        r'"?(?P<field>([Aa]lbum|[Aa]rtist|[Ff]ile[name]*|[Tt]itle|[Aa]ny))"? '
         r'"(?P<what>[^"]+)"')
     query = {}
     for query_part in query_parts:
         m = re.match(query_part_pattern, query_part)
         field = m.groupdict()['field'].lower()
-        if field == u'title':
-            field = u'track'
-        field = str(field) # Needed for kwargs keys on OS X and Windows
-        what = m.groupdict()['what'].lower()
+        if field == 'title':
+            field = 'track'
+        elif field in ('file', 'filename'):
+            field = 'uri'
+        field = str(field)  # Needed for kwargs keys on OS X and Windows
+        what = m.groupdict()['what']
+        if not what:
+            raise ValueError
         if field in query:
             query[field].append(what)
         else:
             query[field] = [what]
     return query
 
+
 @handle_request(r'^count "(?P<tag>[^"]+)" "(?P<needle>[^"]*)"$')
 def count(context, tag, needle):
     """
@@ -39,11 +47,12 @@ def count(context, tag, needle):
         Counts the number of songs and their total playtime in the db
         matching ``TAG`` exactly.
     """
-    return [('songs', 0), ('playtime', 0)] # TODO
+    return [('songs', 0), ('playtime', 0)]  # TODO
 
-@handle_request(r'^find '
-     r'(?P<mpd_query>("?([Aa]lbum|[Aa]rtist|[Dd]ate|[Ff]ilename|'
-     r'[Tt]itle|[Aa]ny)"? "[^"]+"\s?)+)$')
+
+@handle_request(
+    r'^find (?P<mpd_query>("?([Aa]lbum|[Aa]rtist|[Dd]ate|[Ff]ile[name]*|'
+    r'[Tt]itle|[Aa]ny)"? "[^"]*"\s?)+)$')
 def find(context, mpd_query):
     """
     *musicpd.org, music database section:*
@@ -67,14 +76,20 @@ def find(context, mpd_query):
     *ncmpcpp:*
 
     - also uses the search type "date".
+    - uses "file" instead of "filename".
     """
-    query = _build_query(mpd_query)
-    return playlist_to_mpd_format(
-        context.backend.library.find_exact(**query).get())
+    try:
+        query = _build_query(mpd_query)
+    except ValueError:
+        return
+    return tracks_to_mpd_format(
+        context.core.library.find_exact(**query).get())
 
-@handle_request(r'^findadd '
-     r'(?P<query>("?([Aa]lbum|[Aa]rtist|[Ff]ilename|[Tt]itle|[Aa]ny)"? '
-     '"[^"]+"\s?)+)$')
+
+@handle_request(
+    r'^findadd '
+    r'(?P<query>("?([Aa]lbum|[Aa]rtist|[Ff]ilename|[Tt]itle|[Aa]ny)"? '
+    r'"[^"]+"\s?)+)$')
 def findadd(context, query):
     """
     *musicpd.org, music database section:*
@@ -88,8 +103,10 @@ def findadd(context, query):
     # TODO Add result to current playlist
     #result = context.find(query)
 
-@handle_request(r'^list "?(?P<field>([Aa]rtist|[Aa]lbum|[Dd]ate|[Gg]enre))"?'
-    '( (?P<mpd_query>.*))?$')
+
+@handle_request(
+    r'^list "?(?P<field>([Aa]rtist|[Aa]lbum|[Dd]ate|[Gg]enre))"?'
+    r'( (?P<mpd_query>.*))?$')
 def list_(context, field, mpd_query=None):
     """
     *musicpd.org, music database section:*
@@ -100,9 +117,7 @@ def list_(context, field, mpd_query=None):
         ``artist``, ``date``, or ``genre``.
 
         ``ARTIST`` is an optional parameter when type is ``album``,
-        ``date``, or ``genre``.
-
-        This filters the result list by an artist.
+        ``date``, or ``genre``. This filters the result list by an artist.
 
     *Clarifications:*
 
@@ -175,15 +190,19 @@ def list_(context, field, mpd_query=None):
     - capitalizes the field argument.
     """
     field = field.lower()
-    query = _list_build_query(field, mpd_query)
-    if field == u'artist':
+    try:
+        query = _list_build_query(field, mpd_query)
+    except ValueError:
+        return
+    if field == 'artist':
         return _list_artist(context, query)
-    elif field == u'album':
+    elif field == 'album':
         return _list_album(context, query)
-    elif field == u'date':
+    elif field == 'date':
         return _list_date(context, query)
-    elif field == u'genre':
-        pass # TODO We don't have genre in our internal data structures yet
+    elif field == 'genre':
+        pass  # TODO We don't have genre in our internal data structures yet
+
 
 def _list_build_query(field, mpd_query):
     """Converts a ``list`` query to a Mopidy query."""
@@ -194,57 +213,66 @@ def _list_build_query(field, mpd_query):
         tokens = shlex.split(mpd_query.encode('utf-8'))
     except ValueError as error:
         if str(error) == 'No closing quotation':
-            raise MpdArgError(u'Invalid unquoted character', command=u'list')
+            raise MpdArgError('Invalid unquoted character', command='list')
         else:
             raise
     tokens = [t.decode('utf-8') for t in tokens]
     if len(tokens) == 1:
-        if field == u'album':
+        if field == 'album':
+            if not tokens[0]:
+                raise ValueError
             return {'artist': [tokens[0]]}
         else:
             raise MpdArgError(
-                u'should be "Album" for 3 arguments', command=u'list')
+                'should be "Album" for 3 arguments', command='list')
     elif len(tokens) % 2 == 0:
         query = {}
         while tokens:
             key = tokens[0].lower()
-            key = str(key) # Needed for kwargs keys on OS X and Windows
+            key = str(key)  # Needed for kwargs keys on OS X and Windows
             value = tokens[1]
             tokens = tokens[2:]
-            if key not in (u'artist', u'album', u'date', u'genre'):
-                raise MpdArgError(u'not able to parse args', command=u'list')
+            if key not in ('artist', 'album', 'date', 'genre'):
+                raise MpdArgError('not able to parse args', command='list')
+            if not value:
+                raise ValueError
             if key in query:
                 query[key].append(value)
             else:
                 query[key] = [value]
         return query
     else:
-        raise MpdArgError(u'not able to parse args', command=u'list')
+        raise MpdArgError('not able to parse args', command='list')
+
 
 def _list_artist(context, query):
     artists = set()
-    playlist = context.backend.library.find_exact(**query).get()
-    for track in playlist.tracks:
+    tracks = context.core.library.find_exact(**query).get()
+    for track in tracks:
         for artist in track.artists:
-            artists.add((u'Artist', artist.name))
+            if artist.name:
+                artists.add(('Artist', artist.name))
     return artists
 
+
 def _list_album(context, query):
     albums = set()
-    playlist = context.backend.library.find_exact(**query).get()
-    for track in playlist.tracks:
-        if track.album is not None:
-            albums.add((u'Album', track.album.name))
+    tracks = context.core.library.find_exact(**query).get()
+    for track in tracks:
+        if track.album and track.album.name:
+            albums.add(('Album', track.album.name))
     return albums
 
+
 def _list_date(context, query):
     dates = set()
-    playlist = context.backend.library.find_exact(**query).get()
-    for track in playlist.tracks:
-        if track.date is not None:
-            dates.add((u'Date', track.date))
+    tracks = context.core.library.find_exact(**query).get()
+    for track in tracks:
+        if track.date:
+            dates.add(('Date', track.date))
     return dates
 
+
 @handle_request(r'^listall "(?P<uri>[^"]+)"')
 def listall(context, uri):
     """
@@ -254,7 +282,8 @@ def listall(context, uri):
 
         Lists all songs and directories in ``URI``.
     """
-    raise MpdNotImplemented # TODO
+    raise MpdNotImplemented  # TODO
+
 
 @handle_request(r'^listallinfo "(?P<uri>[^"]+)"')
 def listallinfo(context, uri):
@@ -266,7 +295,8 @@ def listallinfo(context, uri):
         Same as ``listall``, except it also returns metadata info in the
         same format as ``lsinfo``.
     """
-    raise MpdNotImplemented # TODO
+    raise MpdNotImplemented  # TODO
+
 
 @handle_request(r'^lsinfo$')
 @handle_request(r'^lsinfo "(?P<uri>[^"]*)"$')
@@ -286,9 +316,10 @@ def lsinfo(context, uri=None):
     directories located at the root level, for both ``lsinfo``, ``lsinfo
     ""``, and ``lsinfo "/"``.
     """
-    if uri is None or uri == u'/' or uri == u'':
+    if uri is None or uri == '/' or uri == '':
         return stored_playlists.listplaylists(context)
-    raise MpdNotImplemented # TODO
+    raise MpdNotImplemented  # TODO
+
 
 @handle_request(r'^rescan( "(?P<uri>[^"]+)")*$')
 def rescan(context, uri=None):
@@ -301,9 +332,10 @@ def rescan(context, uri=None):
     """
     return update(context, uri, rescan_unmodified_files=True)
 
-@handle_request(r'^search '
-     r'(?P<mpd_query>("?([Aa]lbum|[Aa]rtist|[Dd]ate|[Ff]ilename|'
-     r'[Tt]itle|[Aa]ny)"? "[^"]+"\s?)+)$')
+
+@handle_request(
+    r'^search (?P<mpd_query>("?([Aa]lbum|[Aa]rtist|[Dd]ate|[Ff]ile[name]*|'
+    r'[Tt]itle|[Aa]ny)"? "[^"]*"\s?)+)$')
 def search(context, mpd_query):
     """
     *musicpd.org, music database section:*
@@ -330,10 +362,15 @@ def search(context, mpd_query):
     *ncmpcpp:*
 
     - also uses the search type "date".
+    - uses "file" instead of "filename".
     """
-    query = _build_query(mpd_query)
-    return playlist_to_mpd_format(
-        context.backend.library.search(**query).get())
+    try:
+        query = _build_query(mpd_query)
+    except ValueError:
+        return
+    return tracks_to_mpd_format(
+        context.core.library.search(**query).get())
+
 
 @handle_request(r'^update( "(?P<uri>[^"]+)")*$')
 def update(context, uri=None, rescan_unmodified_files=False):
@@ -352,4 +389,4 @@ def update(context, uri=None, rescan_unmodified_files=False):
         identifying the update job. You can read the current job id in the
         ``status`` response.
     """
-    return {'updating_db': 0} # TODO
+    return {'updating_db': 0}  # TODO
