@@ -1,17 +1,20 @@
+from __future__ import unicode_literals
+
 import os
 import re
 
 from mopidy import settings
 from mopidy.frontends.mpd import protocol
-from mopidy.models import CpTrack
+from mopidy.models import TlTrack
 from mopidy.utils.path import mtime as get_mtime, uri_to_path, split_path
 
+
 def track_to_mpd_format(track, position=None):
     """
     Format track for output to MPD client.
 
     :param track: the track
-    :type track: :class:`mopidy.models.Track` or :class:`mopidy.models.CpTrack`
+    :type track: :class:`mopidy.models.Track` or :class:`mopidy.models.TlTrack`
     :param position: track's position in playlist
     :type position: integer
     :param key: if we should set key
@@ -20,10 +23,10 @@ def track_to_mpd_format(track, position=None):
     :type mtime: boolean
     :rtype: list of two-tuples
     """
-    if isinstance(track, CpTrack):
-        (cpid, track) = track
+    if isinstance(track, TlTrack):
+        (tlid, track) = track
     else:
-        (cpid, track) = (None, track)
+        (tlid, track) = (None, track)
     result = [
         ('file', track.uri or ''),
         ('Time', track.length and (track.length // 1000) or 0),
@@ -40,16 +43,16 @@ def track_to_mpd_format(track, position=None):
     if track.album is not None and track.album.artists:
         artists = artists_to_mpd_format(track.album.artists)
         result.append(('AlbumArtist', artists))
-    if position is not None and cpid is not None:
+    if position is not None and tlid is not None:
         result.append(('Pos', position))
-        result.append(('Id', cpid))
+        result.append(('Id', tlid))
     if track.album is not None and track.album.musicbrainz_id is not None:
         result.append(('MUSICBRAINZ_ALBUMID', track.album.musicbrainz_id))
     # FIXME don't use first and best artist?
     # FIXME don't duplicate following code?
     if track.album is not None and track.album.artists:
-        artists = filter(lambda a: a.musicbrainz_id is not None,
-            track.album.artists)
+        artists = filter(
+            lambda a: a.musicbrainz_id is not None, track.album.artists)
         if artists:
             result.append(
                 ('MUSICBRAINZ_ALBUMARTISTID', artists[0].musicbrainz_id))
@@ -61,16 +64,19 @@ def track_to_mpd_format(track, position=None):
         result.append(('MUSICBRAINZ_TRACKID', track.musicbrainz_id))
     return result
 
+
 MPD_KEY_ORDER = '''
     key file Time Artist AlbumArtist Title Album Track Date MUSICBRAINZ_ALBUMID
     MUSICBRAINZ_ALBUMARTISTID MUSICBRAINZ_ARTISTID MUSICBRAINZ_TRACKID mtime
 '''.split()
 
+
 def order_mpd_track_info(result):
     """
-    Order results from :func:`mopidy.frontends.mpd.translator.track_to_mpd_format`
-    so that it matches MPD's ordering. Simply a cosmetic fix for easier
-    diffing of tag_caches.
+    Order results from
+    :func:`mopidy.frontends.mpd.translator.track_to_mpd_format` so that it
+    matches MPD's ordering. Simply a cosmetic fix for easier diffing of
+    tag_caches.
 
     :param result: the track info
     :type result: list of tuples
@@ -78,6 +84,7 @@ def order_mpd_track_info(result):
     """
     return sorted(result, key=lambda i: MPD_KEY_ORDER.index(i[0]))
 
+
 def artists_to_mpd_format(artists):
     """
     Format track artists for output to MPD client.
@@ -88,7 +95,8 @@ def artists_to_mpd_format(artists):
     """
     artists = list(artists)
     artists.sort(key=lambda a: a.name)
-    return u', '.join([a.name for a in artists if a.name])
+    return ', '.join([a.name for a in artists if a.name])
+
 
 def tracks_to_mpd_format(tracks, start=0, end=None):
     """
@@ -98,7 +106,7 @@ def tracks_to_mpd_format(tracks, start=0, end=None):
 
     :param tracks: the tracks
     :type tracks: list of :class:`mopidy.models.Track` or
-        :class:`mopidy.models.CpTrack`
+        :class:`mopidy.models.TlTrack`
     :param start: position of first track to include in output
     :type start: int (positive or negative)
     :param end: position after last track to include in output
@@ -115,6 +123,7 @@ def tracks_to_mpd_format(tracks, start=0, end=None):
         result.append(track_to_mpd_format(track, position))
     return result
 
+
 def playlist_to_mpd_format(playlist, *args, **kwargs):
     """
     Format playlist for output to MPD client.
@@ -123,6 +132,7 @@ def playlist_to_mpd_format(playlist, *args, **kwargs):
     """
     return tracks_to_mpd_format(playlist.tracks, *args, **kwargs)
 
+
 def tracks_to_tag_cache_format(tracks):
     """
     Format list of tracks for output to MPD tag cache
@@ -141,6 +151,7 @@ def tracks_to_tag_cache_format(tracks):
     _add_to_tag_cache(result, *tracks_to_directory_tree(tracks))
     return result
 
+
 def _add_to_tag_cache(result, folders, files):
     music_folder = settings.LOCAL_MUSIC_PATH
     regexp = '^' + re.escape(music_folder).rstrip('/') + '/?'
@@ -165,10 +176,11 @@ def _add_to_tag_cache(result, folders, files):
         result.extend(track_result)
     result.append(('songList end',))
 
+
 def tracks_to_directory_tree(tracks):
     directories = ({}, [])
     for track in tracks:
-        path = u''
+        path = ''
         current = directories
 
         local_folder = settings.LOCAL_MUSIC_PATH
