@@ -1,4 +1,4 @@
-import sys
+from __future__ import unicode_literals
 
 from mopidy import settings
 from mopidy.backends.local import LocalBackend
@@ -11,19 +11,14 @@ from tests.backends.base.playback import PlaybackControllerTest
 from tests.backends.local import generate_song
 
 
-@unittest.skipIf(sys.platform == 'win32',
-    'Our Windows build server does not support GStreamer yet')
 class LocalPlaybackControllerTest(PlaybackControllerTest, unittest.TestCase):
     backend_class = LocalBackend
-    tracks = [Track(uri=generate_song(i), length=4464)
-        for i in range(1, 4)]
+    tracks = [
+        Track(uri=generate_song(i), length=4464) for i in range(1, 4)]
 
     def setUp(self):
         settings.BACKENDS = ('mopidy.backends.local.LocalBackend',)
-
         super(LocalPlaybackControllerTest, self).setUp()
-        # Two tests does not work at all when using the fake sink
-        #self.backend.playback.use_fake_sink()
 
     def tearDown(self):
         super(LocalPlaybackControllerTest, self).tearDown()
@@ -32,10 +27,10 @@ class LocalPlaybackControllerTest(PlaybackControllerTest, unittest.TestCase):
     def add_track(self, path):
         uri = path_to_uri(path_to_data_dir(path))
         track = Track(uri=uri, length=4464)
-        self.backend.current_playlist.add(track)
+        self.tracklist.add([track])
 
     def test_uri_scheme(self):
-        self.assertIn('file', self.backend.uri_schemes)
+        self.assertIn('file', self.core.uri_schemes)
 
     def test_play_mp3(self):
         self.add_track('blank.mp3')
