@@ -1,5 +1,7 @@
 # encoding: utf-8
 
+from __future__ import unicode_literals
+
 import glib
 import os
 import shutil
@@ -58,61 +60,61 @@ class GetOrCreateFolderTest(unittest.TestCase):
 class PathToFileURITest(unittest.TestCase):
     def test_simple_path(self):
         if sys.platform == 'win32':
-            result = path.path_to_uri(u'C:/WINDOWS/clock.avi')
+            result = path.path_to_uri('C:/WINDOWS/clock.avi')
             self.assertEqual(result, 'file:///C://WINDOWS/clock.avi')
         else:
-            result = path.path_to_uri(u'/etc/fstab')
+            result = path.path_to_uri('/etc/fstab')
             self.assertEqual(result, 'file:///etc/fstab')
 
     def test_folder_and_path(self):
         if sys.platform == 'win32':
-            result = path.path_to_uri(u'C:/WINDOWS/', u'clock.avi')
+            result = path.path_to_uri('C:/WINDOWS/', 'clock.avi')
             self.assertEqual(result, 'file:///C://WINDOWS/clock.avi')
         else:
-            result = path.path_to_uri(u'/etc', u'fstab')
-            self.assertEqual(result, u'file:///etc/fstab')
+            result = path.path_to_uri('/etc', 'fstab')
+            self.assertEqual(result, 'file:///etc/fstab')
 
     def test_space_in_path(self):
         if sys.platform == 'win32':
-            result = path.path_to_uri(u'C:/test this')
+            result = path.path_to_uri('C:/test this')
             self.assertEqual(result, 'file:///C://test%20this')
         else:
-            result = path.path_to_uri(u'/tmp/test this')
-            self.assertEqual(result, u'file:///tmp/test%20this')
+            result = path.path_to_uri('/tmp/test this')
+            self.assertEqual(result, 'file:///tmp/test%20this')
 
     def test_unicode_in_path(self):
         if sys.platform == 'win32':
-            result = path.path_to_uri(u'C:/æøå')
+            result = path.path_to_uri('C:/æøå')
             self.assertEqual(result, 'file:///C://%C3%A6%C3%B8%C3%A5')
         else:
-            result = path.path_to_uri(u'/tmp/æøå')
-            self.assertEqual(result, u'file:///tmp/%C3%A6%C3%B8%C3%A5')
+            result = path.path_to_uri('/tmp/æøå')
+            self.assertEqual(result, 'file:///tmp/%C3%A6%C3%B8%C3%A5')
 
 
 class UriToPathTest(unittest.TestCase):
     def test_simple_uri(self):
         if sys.platform == 'win32':
             result = path.uri_to_path('file:///C://WINDOWS/clock.avi')
-            self.assertEqual(result, u'C:/WINDOWS/clock.avi')
+            self.assertEqual(result, 'C:/WINDOWS/clock.avi')
         else:
             result = path.uri_to_path('file:///etc/fstab')
-            self.assertEqual(result, u'/etc/fstab')
+            self.assertEqual(result, '/etc/fstab')
 
     def test_space_in_uri(self):
         if sys.platform == 'win32':
             result = path.uri_to_path('file:///C://test%20this')
-            self.assertEqual(result, u'C:/test this')
+            self.assertEqual(result, 'C:/test this')
         else:
-            result = path.uri_to_path(u'file:///tmp/test%20this')
-            self.assertEqual(result, u'/tmp/test this')
+            result = path.uri_to_path('file:///tmp/test%20this')
+            self.assertEqual(result, '/tmp/test this')
 
     def test_unicode_in_uri(self):
         if sys.platform == 'win32':
-            result = path.uri_to_path( 'file:///C://%C3%A6%C3%B8%C3%A5')
-            self.assertEqual(result, u'C:/æøå')
+            result = path.uri_to_path('file:///C://%C3%A6%C3%B8%C3%A5')
+            self.assertEqual(result, 'C:/æøå')
         else:
-            result = path.uri_to_path(u'file:///tmp/%C3%A6%C3%B8%C3%A5')
-            self.assertEqual(result, u'/tmp/æøå')
+            result = path.uri_to_path('file:///tmp/%C3%A6%C3%B8%C3%A5')
+            self.assertEqual(result, '/tmp/æøå')
 
 
 class SplitPathTest(unittest.TestCase):
@@ -125,11 +127,9 @@ class SplitPathTest(unittest.TestCase):
     def test_folders(self):
         self.assertEqual(['foo', 'bar', 'baz'], path.split_path('foo/bar/baz'))
 
-    def test_folders(self):
-        self.assertEqual(['foo', 'bar', 'baz'], path.split_path('foo/bar/baz'))
-
     def test_initial_slash_is_ignored(self):
-        self.assertEqual(['foo', 'bar', 'baz'], path.split_path('/foo/bar/baz'))
+        self.assertEqual(
+            ['foo', 'bar', 'baz'], path.split_path('/foo/bar/baz'))
 
     def test_only_slash(self):
         self.assertEqual([], path.split_path('/'))
@@ -145,17 +145,20 @@ class ExpandPathTest(unittest.TestCase):
         self.assertEqual('/tmp/foo', path.expand_path('/tmp/foo'))
 
     def test_home_dir_expansion(self):
-        self.assertEqual(os.path.expanduser('~/foo'), path.expand_path('~/foo'))
+        self.assertEqual(
+            os.path.expanduser('~/foo'), path.expand_path('~/foo'))
 
     def test_abspath(self):
         self.assertEqual(os.path.abspath('./foo'), path.expand_path('./foo'))
 
     def test_xdg_subsititution(self):
-        self.assertEqual(glib.get_user_data_dir() + '/foo',
+        self.assertEqual(
+            glib.get_user_data_dir() + '/foo',
             path.expand_path('$XDG_DATA_DIR/foo'))
 
     def test_xdg_subsititution_unknown(self):
-        self.assertEqual('/tmp/$XDG_INVALID_DIR/foo',
+        self.assertEqual(
+            '/tmp/$XDG_INVALID_DIR/foo',
             path.expand_path('/tmp/$XDG_INVALID_DIR/foo'))
 
 
@@ -177,8 +180,8 @@ class FindFilesTest(unittest.TestCase):
     def test_names_are_unicode(self):
         is_unicode = lambda f: isinstance(f, unicode)
         for name in self.find(''):
-            self.assert_(is_unicode(name),
-                '%s is not unicode object' % repr(name))
+            self.assert_(
+                is_unicode(name), '%s is not unicode object' % repr(name))
 
     def test_ignores_hidden_folders(self):
         self.assertEqual(self.find('.hidden'), [])
